@@ -1,9 +1,12 @@
 import boto3
-from jsonpath_ng import jsonpath, parse
+import json
+import pandas as pd
+from jsonpath_ng import jsonpath
+from jsonpath_ng.ext import parse
 
 #####################################
 
-def fields(data, args):
+def fields(args, data):
     f = args.get('fields',[])
     if not f: return data
     d = {}
@@ -14,13 +17,12 @@ def fields(data, args):
 
 #####################################
 
-def found(args,d2):
+def found(args, data):
     f = args.get('filter',[])
     if not f: return True
-    for key,val in f.items():
-        for i in parse(key).find(d2):
-            if i.value in val:
-                return True
+    for je in f:
+        if [match.value for match in parse(je).find([data])]:
+            return True
     return False
 
 #####################################
@@ -28,9 +30,8 @@ def found(args,d2):
 class paginate():
     def __init__(self, session, **kargs):
         self.json = []
-        self.session = session
-        for page in self.session.client(kargs.get('service')).get_paginator(kargs.get('ep')).paginate():
-            self.response = [fields(i.value, kargs) for i in self.jsonpath_expression().find(page) if found(kargs, i.value)]
+        for page in session.client(kargs.get('service')).get_paginator(kargs.get('ep')).paginate():
+            self.json = [fields(kargs, i.value) for i in self.jsonpath_expression().find(page) if found(kargs, i.value)]
         self.df = pd.json_normalize(self.json)
 
             
@@ -46,4 +47,19 @@ class ec2_paginate(paginate):
         paginate.__init__(self, session, **kargs)
 
 #####################################
+
+class org_paginate(paginate):
+    def __init__(self, session, **kargs):
+        kargs.update({'ep':self.name()})
+        kargs.update({'service':'organizations'})
+        paginate.__init__(self, session, **kargs)
+
+#####################################
+
+class s3_paginate(paginate):
+    def __init__(self, session, **kargs):
+        kargs.update({'ep':self.name()})
+        kargs.update({'service':'s3'})
+        paginate.__init__(self, session, **kargs)
+
 #####################################
